@@ -71,7 +71,6 @@ class ExceptionMiddleware:
             await self.app(scope, receive, sender)
         except Exception as exc:
             handler = None
-            request_class = scope["app"].factory_class["http"]
 
             if isinstance(exc, HTTPException):
                 handler = self._status_handlers.get(exc.status_code)
@@ -86,7 +85,7 @@ class ExceptionMiddleware:
                 msg = "Caught handled exception, but response already started."
                 raise RuntimeError(msg) from exc
 
-            request = request_class(scope, receive, send)
+            request = scope["app"].factory_class.http(scope, receive, send)
             if asyncio.iscoroutinefunction(handler):
                 response = await handler(request, exc)
             else:
